OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Nie możesz usunąć własnego uprawnienia do odczytu.",
    "Team folders" : "Foldery zespołów",
    "Unset" : "Usuń z ustawienia",
    "Denied (Inherited permission)" : "Odmówiony (uprawnienia dziedziczone)",
    "Allowed (Inherited permission)" : "Dozwolony (uprawnienia dziedziczone)",
    "Denied" : "Odmówiony",
    "Allowed" : "Dozwolony",
    "Access denied" : "Odmowa dostępu",
    "Access allowed" : "Dostęp dozwolony",
    "Inherit permission" : "Dziedzicz uprawnienie",
    "Deny" : "Odrzuć",
    "Allow" : "Akceptuj",
    "Group" : "Grupa",
    "Team" : "Zespół",
    "Team folder" : "Folder zespołu",
    "Read" : "Odczytaj",
    "Write" : "Zapisz",
    "Create" : "Utwórz",
    "Delete" : "Usuń",
    "Share" : "Udostępnij",
    "You" : "Ty",
    "Remove access rule" : "Usuń regułę dostępu",
    "Add advanced permission rule" : "Dodaj zaawansowaną regułę uprawnień",
    "Select a user or group" : "Wybierz użytkownika lub grupę",
    "Open Team folder" : "Otwórz Folder zespołu",
    "Permission denied. User does not have sufficient permissions." : "Odmowa dostępu. Użytkownik nie ma wystarczających uprawnień.",
    "Unexpected status from server" : "Nieoczekiwany status z serwera",
    "List of Team folders." : "Lista Folderów zespołów",
    "No Team folders yet" : "Brak Folderów zespołów",
    "Team folders will show up here" : "Foldery zespołów pojawią się tutaj",
    "Add group" : "Dodaj grupę",
    "Default" : "Domyślny",
    "Unlimited" : "Bez limitu",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Czy na pewno chcesz usunąć \"{folderName}\" i wszystkie pliki znajdujące się w nim? Tej operacji nie można cofnąć.",
    "Delete \"{folderName}\"?" : "Usunąć \"{folderName}\"?",
    "Team folder admin delegation" : "Delegacja administratora Folderów zespołów",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloud pozwala delegować administrację Folderów zespołów użytkownikom niebędącym administratorami.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Określ poniżej grupy, które będą mogły zarządzać Folderami zespołów i korzystać z ich API/REST.",
    "They will have access to all Team folders." : "Będą mieli dostęp do wszystkich Folderów zespołów.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Określ poniżej grupy, które będą mogły tylko zarządzać Folderami zespołów i korzystać z ich API/REST.",
    "They will only have access to Team folders for which they have advanced permissions." : "Będą mieli dostęp tylko do Folderów zespołów, do których mają rozszerzone uprawnienia.",
    "Group or team" : "Grupa lub zespół",
    "Sort by number of groups or teams that have access to this folder" : "Sortuj według liczby grup lub zespołów mających dostęp do tego folderu",
    "Sort by number of groups that have access to this folder" : "Sortuj według liczby grup mających dostęp do tego folderu",
    "Folder name" : "Nazwa katalogu",
    "Quota" : "Limit",
    "Advanced Permissions" : "Zaawansowane uprawnienia",
    "Pagination of team folders" : "Stronicowanie Folderów zespołów",
    "Previous" : "Poprzednie",
    "Next" : "Następna",
    "User" : "Użytkownik",
    "Unknown" : "Nieznany",
    "Users/groups that can manage" : "Użytkownicy/grupy, które mogą zarządzać",
    "None" : "Brak",
    "No other groups or teams available" : "Brak dostępnych innych grup lub zespołów",
    "No other groups available" : "Brak innych dostępnych grup",
    "{displayName} (team)" : "{displayName} (zespół)",
    "Add group or team" : "Dodaj grupę lub zespół",
    "{size} used" : "Wykorzystane: {size}",
    "Other …" : "Inne …",
    "Admin configured folders shared with everyone in a team" : "Foldery skonfigurowane przez administratora, współdzielone ze wszystkimi w zespole",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Foldery skonfigurowane przez administratora, współdzielone ze wszystkimi w zespole. \n\nFoldery można konfigurować z poziomu Folderów zespołów w ustawieniach administracyjnych. \n\nPo utworzeniu folderu administrator może udzielić dostępu do niego jednej lub kilku drużynom, kontrolować ich uprawnienia do zapisu/udostępniania oraz przypisać kwotę dla folderu.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Foldery skonfigurowane przez administratora, współdzielone ze wszystkimi w zespole. \n\nFoldery można konfigurować z poziomu Folderów zespołów w ustawieniach administracyjnych. \n\nPo utworzeniu folderu administrator może udzielić dostępu do niego jednemu lub kilku zespołom, kontrolować ich uprawnienia do zapisu/udostępniania oraz przypisać kwotę dla folderu. \nOd wersji Hub 10/Nextcloud 31 administrator musi być członkiem zespołu, aby móc przypisać mu Folder zespołu."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
